@@ -32,16 +32,6 @@
 
 #include <libcaja-extension/caja-extension-types.h>
 
-#if PY_MAJOR_VERSION >= 3
-#define STRING_FROMSTRING(str)	PyUnicode_FromString(str)
-#define INT_FROMSSIZE_T(val)    PyLong_FromSsize_t(val)
-#define INT_ASSSIZE_T(obj)      PyLong_AsSsize_t(obj)
-#else
-#define STRING_FROMSTRING(str)	PyString_FromString(str)
-#define INT_FROMSSIZE_T(val)    PyInt_FromSsize_t(val)
-#define INT_ASSSIZE_T(obj)      PyInt_AsSsize_t(obj)
-#endif
-
 static const GDebugKey caja_python_debug_keys[] = {
 	{"misc", CAJA_PYTHON_DEBUG_MISC},
 };
@@ -58,13 +48,13 @@ static GList *all_pyfiles = NULL;
 static PyObject *
 caja_operationhandle_get_handle(PyGBoxed *self, void *closure)
 {
-	return INT_FROMSSIZE_T((Py_ssize_t) (size_t) self->boxed);
+	return PyLong_FromSsize_t((Py_ssize_t) (size_t) self->boxed);
 }
 
 static int
 caja_operationhandle_set_handle(PyGBoxed *self, PyObject *value, void *closure)
 {
-	Py_ssize_t val = INT_ASSSIZE_T(value);
+	Py_ssize_t val = PyLong_AsSsize_t(value);
 
 	if (!PyErr_Occurred()) {
 		if (val) {
@@ -85,7 +75,7 @@ static PyGetSetDef caja_operationhandle_handle = {
 };
 
 
-static inline gboolean 
+static inline gboolean
 np_init_pygobject(void)
 {
     PyObject *gobject = pygobject_init (PYGOBJECT_MAJOR_VERSION, PYGOBJECT_MINOR_VERSION, PYGOBJECT_MICRO_VERSION);
@@ -99,7 +89,7 @@ np_init_pygobject(void)
 }
 
 static void
-caja_python_load_file(GTypeModule *type_module, 
+caja_python_load_file(GTypeModule *type_module,
 						  const gchar *filename)
 {
 	PyObject *main_module, *main_locals, *locals, *key, *value;
@@ -148,7 +138,7 @@ caja_python_load_file(GTypeModule *type_module,
 }
 
 static void
-caja_python_load_dir (GTypeModule *module, 
+caja_python_load_dir (GTypeModule *module,
 						  const char  *dirname)
 {
 	GDir *dir;
@@ -156,11 +146,11 @@ caja_python_load_dir (GTypeModule *module,
 	gboolean initialized = FALSE;
 
 	debug_enter_args("dirname=%s", dirname);
-	
+
 	dir = g_dir_open(dirname, 0, NULL);
 	if (!dir)
 		return;
-			
+
 	while ((name = g_dir_read_name(dir)))
 	{
 		if (g_str_has_suffix(name, ".py"))
@@ -175,7 +165,7 @@ caja_python_load_dir (GTypeModule *module,
 			if (!initialized)
 			{
 				PyObject *sys_path, *py_path;
-				
+
 				/* n-p python part is initialized on demand (or not
 				* at all if no extensions are found) */
 				if (!caja_python_init_python())
@@ -184,16 +174,16 @@ caja_python_load_dir (GTypeModule *module,
 					g_dir_close(dir);
 					break;
 				}
-				
+
 				/* sys.path.insert(0, dirname) */
 				sys_path = PySys_GetObject("path");
-				py_path = STRING_FROMSTRING(dirname);
+				py_path = PyUnicode_FromString(dirname);
 				PyList_Insert(sys_path, 0, py_path);
 				Py_DECREF(py_path);
 			}
 			caja_python_load_file(module, modulename);
 		}
-	}	
+	}
 }
 
 static gboolean
@@ -201,11 +191,7 @@ caja_python_init_python (void)
 {
 	PyObject *gi, *require_version, *args, *caja, *descr;
 	GModule *libpython;
-#if PY_MAJOR_VERSION >= 3
 	wchar_t *argv[] = { L"caja", NULL };
-#else
-	char *argv[] = { "caja", NULL };
-#endif
 
 	if (Py_IsInitialized())
 		return TRUE;
@@ -222,7 +208,7 @@ caja_python_init_python (void)
 		PyErr_Print();
 		return FALSE;
 	}
-	
+
 	debug("PySys_SetArgv");
 	PySys_SetArgv(1, argv);
 	if (PyErr_Occurred())
@@ -307,7 +293,7 @@ caja_python_init_python (void)
 		return FALSE;
 	}
 	Py_DECREF(descr);
-	
+
 	return TRUE;
 }
 
@@ -334,11 +320,11 @@ caja_module_initialize(GTypeModule *module)
 	caja_python_load_dir(module, DATADIR "/caja-python/extensions");
 
 	// Look in XDG_DATA_DIR, ~/.local/share/caja-python/extensions
-	user_extensions_dir = g_build_filename(g_get_user_data_dir(), 
+	user_extensions_dir = g_build_filename(g_get_user_data_dir(),
 		"caja-python", "extensions", NULL);
 	caja_python_load_dir(module, user_extensions_dir);
 }
- 
+
 void
 caja_module_shutdown(void)
 {
@@ -356,7 +342,7 @@ caja_module_list_types(const GType **types,
 						   int          *num_types)
 {
 	debug_enter();
-	
+
 	*types = (GType*)all_types->data;
 	*num_types = all_types->len;
 }
